<?php

namespace Drupal\slack_rtm\Batch;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\slack_rtm\Entity\SlackRtmMessage;
use Drupal\slack_rtm\SlackRtmApi;



/**
 * Batch Class for Slack RTM.
 *
 * @ingroup slack_rtm
 */
class SlackRtmBatch {

  /**
   * Common batch processing callback for all operations.
   *
   * Required to load our include the proper batch file.
   *
   * @param array $batch
   *   The batch array containing all the datas.
   * @param object &$context
   *   The batch context object.
   */
  public static function batchProcess(array $batch,  &$context) {
    // Set up the vars to use.
    $message = $batch['message'];
    $users = $batch['users'];
    $id = $batch['id'];
    $channels_list = $batch['channels_list'];
    $channel = $channels_list[$id];

    // Show message.
    $msg = t('Now assimilating messages from channel %channel',
      ['%channel' => $channel]
    );
    $context['message'] = '<h2>' . $msg . '</h2>';

    // Grab the user.
    $message['author'] = @$users[$message['user']] ?: NULL;

    // If no user, the leave.
    if ($message['author'] === NULL) {
      return;
    }

    // @todo this feels odd to instantiate this class every time in the batch.
    // I can't extend into this since it is a static class.
    // Need to figure out a better way to handle this.
    $api = new SlackRtmApi();

    // Grab the perma-link for the message.
    $params = [
      'channel' => $id,
      'message_ts' => $message['ts'],
      'token' => $api->getToken('slack_bot_token'),
    ];
    $perma_link = $api->callApi('chat.getPermalink', $params);
    
    // Easier to send this all as one $message var.
    $link = @$perma_link["permalink"] ?: NULL;



    $result = SlackRtmMessage::create();
    $result->set('name', $channel . $message['ts']);
    $result->set('channel', $channel);
    $result->set('message', $message['text']);
    $result->set('permalink', $link);
    $result->set('message_author', $message['author']);
    $result->set('created', strtok($message['ts'], '.'));
    $result->set('tid', $message['ts']);
    $result->save();

    // Set the result.
    $context['results'][] = $result;

  }

  /**
   * Batch finished callback.
   */
  public static function batchFinished($success, $results, $operations) {
    if ($success) {
      $message = \Drupal::translation()->formatPlural(count($results), 'One message assimilated.', '@count messages assimilated.');
      drupal_set_message($message, 'status', TRUE);
    }
    else {
      $error_operation = reset($operations);
      drupal_set_message(t('An error occurred while processing @operation with arguments : @args', array('@operation' => $error_operation[0], '@args' => print_r($error_operation[0], TRUE))), 'status', TRUE);
    }

    // Redirect to Slack RTM page.
    $response = new RedirectResponse('/admin/structure/slack_rtm_message');
    $response->send();
  }
}